{% extends "layout/default.html" %}
{% block body %}

<h1>Bienvenue sur Onyx</h1>
<h3>Pour accéder au blog et pour télécharger Onyx : <a href="https://blog.onyxlabs.fr">blog.onyxlabs.fr</a></h3>

{% endblock %}


   