{% extends "layout/login.html" %}
{% block body %}




 <div class="login-page">
  <form class="register-form" method=post action=""> 
  <div class="form">  
 
      <img style="max-width: 100%; height:250px; " src="{{ url_for('static' , filename='images/logo.png') }}">

      <input type="email" id="email" name="email" class="input-xlarge"
            placeholder="Adresse Email" value="{{ request.form.email }}"
            required>

      <button>M'envoyer un nouveau mot de passe</button>
    </form>
  </div>
</div>

{% endblock %}