<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Onyx | 404</title>
        <link href="{{ url_for('static', filename='css/bootstrap.min.css') }}" rel="stylesheet" type="text/css" />
        <link href='http://fonts.googleapis.com/css?family=Open+Sans:400,600,700,800' rel='stylesheet' type='text/css'>
        <link href="{{ url_for('static', filename='css/404.css') }}" rel="stylesheet" type="text/css" />
    </head>
    <body>
        <section>
            <div class="container">
                <div class="row row1">
                    <div class="col-md-12">
                        <h3 class="center capital f1">Oups !</h3>
                        <h1 id="error" class="center" >404</h1>
                        <p class="center">Page non trouvée ! Revenir à <a href="{{ url_for('index') }}">Onyx</a></p>
                       </div>
                </div>
            </div>
        </section>
    </body>
</html>
