<h2>Modification de votre mot de passe</h2><br>
<p>Bonjour ! Vous venez de demander un nouveau mot de passe , si c'est le cas cliquez sur ce lien :</p>
<p><a href="{{ confirm_url }}">{{ confirm_url }}</a></p>
<br>
<p>Sinon ignorez ce message </p><br>
<p>Onyx Software</p>
