<h2>Bienvenue sur Onyx</h2><br>
<p>Bonjour ! Vous venez de vous inscrire sur Onyx veuillez cliquer sur ce lien pour confirmer votre inscription :</p>
<p><a href="{{ confirm_url }}">{{ confirm_url }}</a></p>
<br>
<p>Merci !</p>
