{% extends "layout/default.html" %}
{% block body %}
		
    <div class="card-panel grey lighten-3">
		        <h2>Mon compte</h2>		 

    <span class="btn-floating btn-large {{ buttonColor }}"></span><br><br>
    <a href="{{ url_for('changeColor') }}" class="btn {{ buttonColor }}">Changer la couleur</a><br>
    <h5>Pseudo</h5> {{ currentUser }}
    <h5>Email</h5>{{ currentEmail }}
		        <h3>Changez mes informations :</h3> <br>

		          <form class="form" method=post action="">
	  <div class="container">
	  <label for="username" >Nouveau pseudo</label>
	  <input type="text" id="username" name="username" value="{{ request.form.username }}">

	  <label for="password" >Nouveau mot de passe</label>
      <input type="password" id="password"  name="password" value="{{ request.form.password }}">

      <label for="email" >Nouvel Email</label>
      <input type="email" id="email" name="email" value="{{ request.form.email }}">

       <label for="lastpassword" >Ancien mot de passe</label>     
      <input type="password" id="lastpassword"  name="lastpassword" value="{{ request.form.lastpassword }}" required>


      </div>

      <br>
      <br>

      <button class="btn {{ buttonColor }}">Enregistrer les modifications</button>
    </form>

  

		 
{% endblock %}